0.3.0 (2020-06-16)
==================

* Switch to rust-cpython
* Fix passing of tcp connections to worker threads

0.2.0 (2020-03-10)
==================

* Added some Python tests (using py.test and tox)
* Improve handling of HTTP headers
* respect content length header when using sendfile

0.1.0 (2020-02-10)
==================

* Initial release
